pub struct DictionarySubstringRule<D: Dictionary> { /* private fields */ }Expand description
Rule for determining if a password contains a dictionary word with optional checking for reversed words.
Example
use passay_rs::dictionary::word_lists::word_list_dictionary::WordListDictionary;
use passay_rs::dictionary::word_lists::ArrayWordList;
use passay_rs::dictionary::word_lists::sort::SliceSort;
use passay_rs::rule::dictionary_substring::DictionarySubstringRule;
use passay_rs::rule::PasswordData;
use passay_rs::rule::Rule;
let words = ["test", "z", "x", "y", "man", "lance"].map(String::from).to_vec();
// world list should be sorted so we sort it now
let word_list = ArrayWordList::with_sorter(words, false, Some(SliceSort));
let dictionary = WordListDictionary::new(word_list);
let dictionary_rule = DictionarySubstringRule::new(dictionary, true);
let password = PasswordData::with_password("p4tlancely5gew".to_string());
let result = dictionary_rule.validate(&password);
assert!(!result.valid());Implementations
Sourceimpl<D: Dictionary> DictionarySubstringRule<D>
impl<D: Dictionary> DictionarySubstringRule<D>
pub fn new(dictionary: D, match_backwards: bool) -> Self
pub fn from_dictionary(dictionary: D) -> Self