DigestSourceRule

Struct DigestSourceRule 

pub struct DigestSourceRule<H>
where H: Hasher<String>,
{ /* private fields */ }
Rule for determining if a password matches a digested password from a different source. Useful for when separate systems cannot have matching passwords. If no password reference has been set that matches the label on the rule, then passwords will meet this rule. See also PasswordData::password_references

Example

 use passay_rs::rule::digest_source::DigestSourceRule;
 use passay_rs::rule::source::SourceReference;
 use passay_rs::rule::reference::Reference;
 use passay_rs::rule::PasswordData;
 use passay_rs::rule::Rule;

 let rule = DigestSourceRule::new(Sha1Hasher, true);
 let source: Vec<Box<dyn Reference>> = vec![Box::new(SourceReference::with_password_label(
     "CJGTDMQRP+rmHApkcijC80aDV0o=".to_string(),
     "System B".to_string(),
 ))];
 let password = PasswordData::new(
     "t3stUs3r04".to_string(),
     Some("testuser".to_string()),
     source,
 );
 let result = rule.validate(&password);
 assert!(!result.valid());

Implementations

Source

impl<H> DigestSourceRule<H>
where H: Hasher<String>,

pub fn new(hasher: H, report_all: bool) -> Self