pub struct LengthRule { /* private fields */ }Expand description
Rule for determining if a password is within a desired length. The minimum and maximum lengths are used inclusively to determine if a password meets this rule.
Example
use passay_rs::rule::PasswordData;
use passay_rs::rule::length::LengthRule;
use passay_rs::rule::Rule;
let rule = LengthRule::new(4, 10);
let password = PasswordData::with_password("123".to_string());
let result = rule.validate(&password);
assert!(!result.valid());Implementations
Sourceimpl LengthRule
impl LengthRule